@@ -60,8 +60,8 @@ enum _Commands { es_init,
 };
 
 typedef struct {
-	GMutex *mutex;
-	GCond *cond;
+	GMutex mutex;
+	GCond cond;
 	gboolean free;
 } AccessStruc;
 
@@ -100,7 +100,7 @@ struct _MiauiGLView {
 	MiaQuaternion *rot_helper;
 	gboolean zoomin_enabled;
 	gboolean abort_rendering; 
-	GMutex   *abort_rendering_mutex;
+	GMutex   abort_rendering_mutex;
 
 	/* Landmark picking */
 	GtkWidget *landmark_menu;
@@ -421,30 +421,30 @@ __send (MiauiGLView * self, Commands command, gpointer data)
 static void
 __access_free (AccessStruc * ac)
 {
-	g_mutex_lock (ac->mutex);
+	g_mutex_lock (&ac->mutex);
 	ac->free = TRUE;
-	g_cond_signal (ac->cond);
+	g_cond_signal (&ac->cond);
 	g_debug("thread %p: free lock %p", g_thread_self(), ac);  
-	g_mutex_unlock (ac->mutex);
+	g_mutex_unlock (&ac->mutex);
 }
 
 static void
 __access_unfree (AccessStruc * ac)
 {
-	g_mutex_lock (ac->mutex);
+	g_mutex_lock (&ac->mutex);
 	g_debug("thread %p: unfree lock %p", g_thread_self(), ac);  
 	ac->free = FALSE;
-	g_mutex_unlock (ac->mutex);
+	g_mutex_unlock (&ac->mutex);
 }
 
 static void
 __access_waitfree (AccessStruc * ac)
 {
-	g_mutex_lock (ac->mutex);
+	g_mutex_lock (&ac->mutex);
 	g_debug("thread %p: wait for %p", g_thread_self(), ac);  
 	while (ac->free == FALSE)
-		g_cond_wait (ac->cond, ac->mutex);
-	g_mutex_unlock (ac->mutex);
+		g_cond_wait (&ac->cond, &ac->mutex);
+	g_mutex_unlock (&ac->mutex);
 }
 
 static void
@@ -462,9 +462,9 @@ __send_wait (MiauiGLView * self, AccessStruc * ac,
 static void
 __abort_rendering(MiauiGLView * self)
 {
-	g_mutex_lock(self->abort_rendering_mutex);
+	g_mutex_lock(&self->abort_rendering_mutex);
 	self->abort_rendering = TRUE;
-	g_mutex_unlock(self->abort_rendering_mutex);
+	g_mutex_unlock(&self->abort_rendering_mutex);
 }
 
 gboolean 
@@ -473,10 +473,10 @@ miaui_glview_check_abort_rendering(MiauiGLView *self)
 	gboolean retval; 
 	if (!self->use_low) 
 		return FALSE; 
-	g_mutex_lock(self->abort_rendering_mutex);
+	g_mutex_lock(&self->abort_rendering_mutex);
 	retval = self->abort_rendering;
 	self->abort_rendering = FALSE;
-	g_mutex_unlock(self->abort_rendering_mutex);
+	g_mutex_unlock(&self->abort_rendering_mutex);
 	return retval; 
 }
 
@@ -805,12 +805,12 @@ __miaui_glview_instance_init (GTypeInstance * instance, gpointer UNUSED(g_class)
 	self->signal_queue = g_async_queue_new ();
 	g_async_queue_ref (self->signal_queue);
 
-	self->view_access.mutex = g_mutex_new ();
-	self->view_access.cond = g_cond_new ();
+	g_mutex_init(&self->view_access.mutex);
+	g_cond_init(&self->view_access.cond);
 	self->view_access.free = TRUE;
 
-	self->data_access.mutex = g_mutex_new ();
-	self->data_access.cond = g_cond_new ();
+	g_mutex_init(&self->data_access.mutex);
+	g_cond_init(&self->data_access.cond);
 	self->data_access.free = TRUE;
 
 	self->rotation_center = mia_vector3d_new(1,1,1); 
@@ -819,8 +819,7 @@ __miaui_glview_instance_init (GTypeInstance * instance, gpointer UNUSED(g_class)
 
 	/* create the GL thread, this also sets the GL capability */
 	self->gl_thread =
-		g_thread_create ((GThreadFunc) __glview_job, self,
-				 TRUE, NULL);
+		g_thread_new ("renderthread", (GThreadFunc) __glview_job, self);
 
 	/* wait for the worker thread to be created   */
 	__access_waitfree(&self->view_access); 
@@ -882,7 +881,7 @@ __miaui_glview_instance_init (GTypeInstance * instance, gpointer UNUSED(g_class)
 	self->l_mouse_dragging = FALSE;
 
 	self->abort_rendering = FALSE; 
-	self->abort_rendering_mutex = g_mutex_new();
+	g_mutex_init(&self->abort_rendering_mutex);
 
 	self->use_low = TRUE;
 
@@ -962,14 +961,8 @@ __miaui_glview_finalize (GObject * obj)
 {
 	MiauiGLViewClass *klass;
 	GObjectClass *parent_class;
-	MiauiGLView *self = (MiauiGLView *) obj;
 
 	/* add your destruction code here */
-	g_mutex_free (self->view_access.mutex);
-	g_cond_free (self->view_access.cond);
-
-	g_mutex_free (self->data_access.mutex);
-	g_cond_free (self->data_access.cond);
 
 	/* chain up to the parent class */
 	klass = MIAUI_GLVIEW_CLASS (g_type_class_peek (MIAUI_TYPE_GLVIEW));
