@@ -602,7 +602,7 @@ __release_cg_env (MiaGLVolume * UNUSED(self))
 }
 
 
-inline void
+static inline void
 __enable_texture (MiaGLVolume * self)
 {
 	glEnable (GL_TEXTURE_3D);
@@ -617,7 +617,7 @@ __enable_texture (MiaGLVolume * self)
 
 }
 
-inline void
+static inline void
 __disable_texture (MiaGLVolume * UNUSED(self))
 {
 	glDisable (GL_TEXTURE_3D);
@@ -628,7 +628,7 @@ gboolean get_render_abort()
 	return miaui_glview_check_abort_rendering(MIAUI_GLVIEW(glview));
 }
 
-inline void
+static inline void
 __draw_xslice(MiaGLVolume *self, float x)
 {
 	gfloat fx = 2 * x * self->sx; 
@@ -672,7 +672,7 @@ __glview_draw_x_slices_m (MiaGLVolume *self, float step, gboolean high)
 	}
 }
 
-inline void 
+static inline void 
 __draw_yslice(MiaGLVolume *self, float y)
 {
 	gfloat fx = 2 * self->sx; 
@@ -716,7 +716,7 @@ __glview_draw_y_slices_p (MiaGLVolume *self, float step, gboolean high)
 	}
 }
 
-inline void 
+static inline void 
 __draw_zslice(MiaGLVolume *self, float z)
 {
 	gfloat fx = 2 * self->sx; 
