@@ -64,6 +64,7 @@ int main (int argc, char *argv[])
 	int help = 0;
 	int usage = 0;
 	poptContext optCon;
+	char *glade_filename = NULL; 
 		
 	struct poptOption options[] = {	
 		{ "landmarkset",  'i', POPT_ARG_STRING, &lm_filename, 0,
@@ -71,7 +72,9 @@ int main (int argc, char *argv[])
 		{ "outputset",  'o', POPT_ARG_STRING, &out_filename, 0,
 		  "output landmark set", "outputset" },
 		{ "volume",  'v', POPT_ARG_STRING, &in_filename, 0,
-		  "volume image", "volume" },
+		  "volume image (only unsigned short and unsigned byte are supported)", "volume" },
+		{ "glade-file",  0, POPT_ARG_STRING, &glade_filename, 0,
+		  "use specified glade interface file (only usefull when run from source tree)", "glade" },
 		POPT_AUTOHELP
                 { NULL, 0, 0, NULL, 0, 0, 0 }
 	};
@@ -134,10 +137,10 @@ int main (int argc, char *argv[])
 
 	g_message("load glade file ... "); 
 			
-	if (!strcmp("mia-lmpick", argv[0]))
+	if ( glade_filename  )
+		xml = glade_xml_new (glade_filename, NULL, NULL);
+	else 
 		xml = glade_xml_new (PACKAGE_DATA_DIR "/mia-lmpick.glade", NULL, NULL);
-	else
-		xml = glade_xml_new (PACKAGE_SOURCE_DIR "/mia-lmpick.glade", NULL, NULL);
 
 	g_message("done"); 
 	if (xml)  {
